@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2002 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2002 Marc Mutz <mutz@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // config keys:
@@ -31,7 +18,6 @@ static const char configKeyDefaultIdentity[] = "Default Identity";
 #include <KConfig>
 #include <KSharedConfig>
 #include <kuser.h>
-#include <KConfigGroup>
 #include <Kdelibs4ConfigMigrator>
 
 #include <QList>
@@ -569,11 +555,11 @@ Identity &IdentityManager::modifyIdentityForName(const QString &name)
     qCWarning(KIDENTITYMANAGEMENT_LOG) << "IdentityManager::modifyIdentityForName() used as"
                                        << "newFromScratch() replacement!"
                                       #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                                       << endl
+        << endl
                                       #else
-                                       << Qt::endl
+        << Qt::endl
                                       #endif
-                                       << "  name == \"" << name << "\"";
+        << "  name == \"" << name << "\"";
     return newFromScratch(name);
 }
 
@@ -588,11 +574,11 @@ Identity &IdentityManager::modifyIdentityForUoid(uint uoid)
     qCWarning(KIDENTITYMANAGEMENT_LOG) << "IdentityManager::identityForUoid() used as"
                                        << "newFromScratch() replacement!"
                                       #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                                       << endl
+        << endl
                                       #else
-                                       << Qt::endl
+        << Qt::endl
                                       #endif
-                                       << "  uoid == \"" << uoid << "\"";
+        << "  uoid == \"" << uoid << "\"";
     return newFromScratch(i18n("Unnamed"));
 }
 
